@@ -91,6 +91,13 @@ def test_heat_definition():
     assert definition['name'] == 'bind-host'
 
 
+def test_heat_definition_encrypted():
+    d = 'tests/enough/common/test_openstack/config_dir'
+    definitions = Heat.get_stack_definitions(share_dir=d, config_dir=d)
+    assert 'my-host' in definitions
+    assert definitions['my-host']['myvariable'] == 'myvalue'
+
+
 def test_create_test_subdomain_no_bind(mocker):
     mocker.patch('os.path.exists', return_value=True)
     mocker.patch('enough.common.openstack.Stack.list', return_value=[])
